package io.scanbot.sdk.flutter.camera.config

import androidx.annotation.Keep
import io.scanbot.sdk.core.contourdetector.PageAspectRatio
import io.scanbot.sdk.persistence.Page
import io.scanbot.sdk.persistence.PageStorageProcessor

@Keep
class DocumentScannerConfiguration {
    var detectDocumentAfterSnap: Boolean? = null
    var autoSnapEnabled: Boolean? = null
    var ignoreBadAspectRatio: Boolean? = null
    var acceptedAngleScore: Float? = null
    var acceptedSizeScore: Float? = null
    var requiredAspectRatios: List<PageAspectRatio>? = null

    /// Changes sensitivity of auto-snapping. That is: the more sensitive it is the faster it shoots.
    /// This parameter only works when `barcodeImageGenerationType = BarcodeImageGenerationType.CAPTURED_IMAGE`
    /// Sensitivity must be within [0..1] range. A value of 1.0 triggers automatic capturing immediately,
    /// a value of 0.0 delays the automatic capturing by 3 seconds.
    ///
    /// The default value is 0.66 (1 sec) so you will get snapped barcode result with saved image each not offen than 1 second.
    ///
    /// @param sensitivity should be within [0..1] range.
    var autoSnapSensitivity: Float? = null

    var originalImageSizeLimit: PageStorageProcessor.Configuration.Size? = null

    var documentImageSizeLimit: PageStorageProcessor.Configuration.Size? = null
}

@Keep
class ContourConfiguration(
    var showPolygonInManualMode: Boolean?,

    var strokeColor: String?,

    var strokeOkColor: String?,

    var fillColor: String?,

    var fillOkColor: String?,

    var autoSnapProgressStrokeColor: String?,

    var strokeWidth: Float?,

    var autoSnapProgressStrokeWidth: Float?,

    var cornerRadius: Float?,

    var autoSnapProgressEnabled: Boolean?

)
