//
//  OCRPerformConfiguration.swift
//  scanbot_sdk
//
//  Created by Zhenya Knizhnik on 03.09.19.
//

import Foundation
import ScanbotSDK

struct OCRPerformConfiguration {
    var languages: [String] = []
    var engine: SBSDKOpticalCharacterRecognitionMode = .ML
    var shouldGeneratePdf: Bool = false
    var pdfOptions =  SBSDKPDFRendererOptions(pageSize: .custom, pageOrientation: .auto, ocrConfiguration: nil)
    var pdfAttributes: [String: Any]?
    let pages: [SBSDKUIPage]
    
    init?(from dictionary: [String: Any]) {
        let configDictionary = dictionary["options"] as? [String: Any]
        if let engine = configDictionary?["engine"] as? String {
            self.engine = SBSDKOpticalCharacterRecognitionMode(string: engine)
        }
        if let languages = configDictionary?["languages"] as? [String] {
            self.languages = languages
        }
        
        if let shouldGeneratePdf = configDictionary?["shouldGeneratePdf"] as? Bool {
            self.shouldGeneratePdf = shouldGeneratePdf
            
            if let pdfOptions = configDictionary?["pdfOptions"] as? [String: Any]  {
                var pageSize: SBSDKPDFRendererPageSize = .custom
                var pageOrientation: SBSDKPDFRendererPageOrientation = .auto
                if let pageSizeString = pdfOptions["pageSize"] as? String {
                    pageSize = SBSDKPDFRendererPageSize(string: pageSizeString)
                }
                if let pageDirection = pdfOptions["pageDirection"] as? String {
                    pageOrientation = SBSDKPDFRendererPageOrientation(string: pageDirection)
                }
                if let pdfAttributes = pdfOptions["pdfAttributes"] as? [String: Any] {
                    self.pdfAttributes = pdfAttributes
                }
                self.pdfOptions = SBSDKPDFRendererOptions(pageSize: pageSize, pageOrientation: pageOrientation, ocrConfiguration: nil)
            }
        }
        
        let pages = SBSDKUIPage.pages(from: dictionary)
        if pages.isEmpty {
            return nil
        }
        
        self.pages = pages
    }
}
