//
//  BarcodeScannerPresenter.swift
//  scanbot_sdk
//
//  Created by Zhenya Knizhnik on 26.08.19.
//

import UIKit
import ScanbotSDK
import Flutter

class BarcodeScannerPresenter: NSObject {
    private var resultHandler: FlutterResult?
    private weak var presenter: UIViewController?
    private var shouldWaitForBarcodeImage = false
    private var detectedBarcodeResults: [SBSDKBarcodeScannerResult]?
    
    func present(on presenter: UIViewController,
                 with configuration: SBSDKUIBarcodeScannerConfiguration,
                 machineCodeTypes: [SBSDKBarcodeType]?,
                 barcodeDocumentTypes: [SBSDKBarcodeDocumentType]?,
                 result: @escaping FlutterResult) {
        self.resultHandler = result
        self.presenter = presenter
        
        self.shouldWaitForBarcodeImage = configuration.behaviorConfiguration.barcodeImageGenerationType != .none
        
        // TODO: Remove after update the SDK version after 4.0.2
        if configuration.behaviorConfiguration.isViewFinderEnabled == false {
             configuration.textConfiguration.finderTextHint = ""
        }
        
        let controller = SBSDKUIBarcodeScannerViewController.createNew(
            with: configuration,
            andDelegate: self)
        
        controller.modalPresentationStyle = .fullScreen
        presenter.present(controller, animated: true, completion: nil)
    }
    
    private func handleResult(barcodeResults: [SBSDKBarcodeScannerResult], barcodeImageURL: URL? = nil) {
        self.presenter?.dismiss(animated: true, completion: { [weak self] in
            let resultDict: [String: Any?] = ["barcodeItems": barcodeResults.map({ $0.encodedDictionary }),
                                              "barcodeImageURI": barcodeImageURL?.absoluteString]
            self?.resultHandler?(resultDict.encodedString)
            self?.resultHandler = nil
            self?.presenter = nil
            self?.detectedBarcodeResults = nil
        })
    }
}

extension BarcodeScannerPresenter: SBSDKUIBarcodeScannerViewControllerDelegate {
    
    func qrBarcodeDetectionViewController(_ viewController: SBSDKUIBarcodeScannerViewController,
                                          didDetect barcodeResults: [SBSDKBarcodeScannerResult]) {
        viewController.isRecognitionEnabled = false
        
        if self.shouldWaitForBarcodeImage {
            self.detectedBarcodeResults = barcodeResults
            return
        }
        
        self.handleResult(barcodeResults: barcodeResults)
    }
    
    func qrBarcodeDetectionViewController(_ viewController: SBSDKUIBarcodeScannerViewController,
                                          didCaptureBarcodeImage barcodeImage: UIImage?,
                                          imageURL: URL?) {
        guard let barcodeResults = self.detectedBarcodeResults else { return }
        self.handleResult(barcodeResults: barcodeResults, barcodeImageURL: imageURL)
    }
    
    func qrBarcodeDetectionViewControllerDidCancel(_ viewController: SBSDKUIBarcodeScannerViewController) {
        self.resultHandler?("CANCELED")
        self.resultHandler = nil
        self.presenter = nil
        self.detectedBarcodeResults = nil
    }
}
