import 'package:flutter/material.dart';

class FadeOutView extends StatefulWidget {
  final Widget? child;
  final Duration fadeDuration;
  final Duration fadeDelay;

  const FadeOutView(
      {Key? key,
      required this.child,
      this.fadeDuration = const Duration(milliseconds: 250),
      this.fadeDelay = const Duration(milliseconds: 250)})
      : super(key: key);

  @override
  State<FadeOutView> createState() => _FadeOutViewState();
}

class _FadeOutViewState extends State<FadeOutView>
    with SingleTickerProviderStateMixin {
  late final AnimationController _controller;
  late final Animation<double> _animation;
  late final CurvedAnimation _curve;

  @override
  void initState() {
    super.initState();
    _controller = AnimationController(
      vsync: this,
      duration: widget.fadeDuration,
    );

    _curve = CurvedAnimation(parent: _controller, curve: Curves.easeIn);

    _animation = Tween(
      begin: 1.0,
      end: 0.0,
    ).animate(_curve);
    _controller.value = 0.0;
    Future.delayed(widget.fadeDelay, () {
      _controller.animateTo(1.0);
    });
  }

  @override
  void dispose() {
    _controller.dispose();
    super.dispose();
  }

  @override
  Widget build(BuildContext context) {
    return Center(
      child: FadeTransition(
        opacity: _animation,
        child: widget.child,
      ),
    );
  }
}
