import 'package:json_annotation/json_annotation.dart';
import 'json/common.dart';
import 'json/mrz_configuration_json.dart';

import 'json/common_generic_document.dart';
import 'sdk_utils.dart';
import 'json/generic_document_wrappers.dart';

part 'mrz_scanning_data.g.dart';

@JsonSerializable(
    createFactory: true,
    includeIfNull: false,
    createToJson: false,
    explicitToJson: false)
class MrzGenericScanningResult extends Result {
  /// mrz generic document
  GenericDocument? document;

  MrzDocumentType documentType = MrzDocumentType.Undefined;

  String rawMrz = "";

  MrzGenericScanningResult(this.documentType, this.rawMrz, this.document);

  MrzGenericScanningResult.error(String message) {
    operationResult = OperationResult.ERROR;
    this.message = message;
  }

  MrzGenericScanningResult.canceled() {
    operationResult = OperationResult.CANCELED;
  }

  factory MrzGenericScanningResult.fromJson(Map<String, dynamic> json) =>
      _$MrzGenericScanningResultFromJson(json);
}

/// This class describes machine readable zone rtu-ui component scanned result
class MrzScanningResult extends Result {
  /// mrz generic document
  MRZ? document;

  MrzDocumentType documentType = MrzDocumentType.Undefined;

  String rawMrz = "";

  MrzScanningResult(this.documentType, this.rawMrz, this.document);

  MrzScanningResult.error(String message) {
    operationResult = OperationResult.ERROR;
    this.message = message;
  }

  MrzScanningResult.canceled() {
    operationResult = OperationResult.CANCELED;
  }

  factory MrzScanningResult.fromJson(Map<String, dynamic> json) {
    final mrzGenericScanningResult = MrzGenericScanningResult.fromJson(json);
    return MrzScanningResult(
        mrzGenericScanningResult.documentType,
        mrzGenericScanningResult.rawMrz,
        mrzGenericScanningResult.document?.let((document) => MRZ(document)));
  }
}

enum MrzDocumentType {
  Undefined,
  CrewMemberCertificate,
  IDCard,
  Passport,
  Visa,
  SwissDriverLicense;
}

/// This class describes machine readable zone rtu-ui component configuration
class MrzScannerConfiguration extends MrzScannerJsonConfiguration {
  /// The configuration object should be applied for this screen
  @override
  String? screen = "MrzScanner";

  MrzScannerConfiguration({
    super.cameraModule,
    super.cameraOverlayColor,
    super.cancelButtonTitle,
    super.cancelButtonHidden,
    super.enableCameraButtonTitle,
    super.enableCameraExplanationText,
    super.finderLineColor,
    super.finderLineWidth,
    super.finderTextHint,
    super.finderTextHintColor,
    super.finderAspectRatio,
    super.flashButtonHidden,
    super.flashButtonTitle,
    super.flashEnabled,
    super.orientationLockMode,
    super.successBeepEnabled,
    super.topBarBackgroundColor,
    super.topBarButtonsActiveColor,
    super.topBarButtonsInactiveColor,
    super.useButtonsAllCaps,
    super.replaceCancelButtonWithIcon,
    super.cameraPreviewMode,
    super.touchToFocusEnabled,
  });
}
